# qolsys_client

Python package to talk to Qolsys Alarm Panels

This package was inspired by a conversation on the Home Assistant forum:

<https://community.home-assistant.io/t/qolsys-iq-panel-2-and-3rd-party-integration/231405>
